@@ -44,19 +44,19 @@ def format_product_symbol(symbol: str) -> str:
     - AAVEUSD → AAVE-USD
     - ETHUSDH25 → ETH-USD-H25
     """
-    match = re.match(r"([A-Z]+)(USD[T]?)-(\d+[A-Z]{3}\d{2})$", symbol)
+    match = re.match(r"([A-Z]+)(USD[T]?)\-([0-9]{2}[A-Z]{3}[0-9]{2})$", symbol)
     if match:
         base, quote, date = match.groups()
         return f"{base}-{quote}-{date}-FUTURES"
 
-    # ETH-25APR25 --> ETH-25APR25-SWAP
+    # ETH-25APR25 --> ETH-25APR25-FUTURES
     match = re.match(r"([A-Z]+)-(\d+[A-Z]{3}\d{2})$", symbol)
     if match:
         base, date = match.groups()
         return f"{base}-{date}-FUTURES"
 
-    # ETHUSDH25 --> ETH-USD-H25-SWAP
-    match = re.match(r"([A-Z]+)(USD[T]?)([HMU]\d{2})$", symbol)
+    # ETHUSDH25 --> ETH-USD-H25-FUTURES
+    match = re.match(r"([A-Z]+)(USD[T]?)([HMUZ]\d{2})$", symbol)
     if match:
         base, quote, date = match.groups()
         return f"{base}-{quote}-{date}-FUTURES"
